from OpenSSL import crypto
import base64
import requests
import random
import string
import json

def randomDigits(self, stringLength=10):
    """Generate a random string of letters and digits """
    return ''.join(random.choice(string.digits) for i in range(stringLength))

class Generic:
    base_url='https://api.transip.nl/v6/auth'
    def __init__(self, login, key, demo = False):
        self.login = login
        self.key = key
        self.demo = demo

    def get_jwt(self):
        if self.demo:
            return 'eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsImp0aSI6ImN3MiFSbDU2eDNoUnkjelM4YmdOIn0.eyJpc3MiOiJhcGkudHJhbnNpcC5ubCIsImF1ZCI6ImFwaS50cmFuc2lwLm5sIiwianRpIjoiY3cyIVJsNTZ4M2hSeSN6UzhiZ04iLCJpYXQiOjE1ODIyMDE1NTAsIm5iZiI6MTU4MjIwMTU1MCwiZXhwIjoyMTE4NzQ1NTUwLCJjaWQiOiI2MDQ0OSIsInJvIjpmYWxzZSwiZ2siOmZhbHNlLCJrdiI6dHJ1ZX0.fYBWV4O5WPXxGuWG-vcrFWqmRHBm9yp0PHiYh_oAWxWxCaZX2Rf6WJfc13AxEeZ67-lY0TA2kSaOCp0PggBb_MGj73t4cH8gdwDJzANVxkiPL1Saqiw2NgZ3IHASJnisUWNnZp8HnrhLLe5ficvb1D9WOUOItmFC2ZgfGObNhlL2y-AMNLT4X7oNgrNTGm-mespo0jD_qH9dK5_evSzS3K8o03gu6p19jxfsnIh8TIVRvNdluYC2wo4qDl5EW5BEZ8OSuJ121ncOT1oRpzXB0cVZ9e5_UVAEr9X3f26_Eomg52-PjrgcRJ_jPIUYbrlo06KjjX2h0fzMr21ZE023Gw'
        pkey = crypto.load_privatekey(crypto.FILETYPE_PEM, self.key)
        data = '{ "login": "' + self.login + '", "nonce": ' + randomDigits(10) + ' }'
        signature = base64.b64encode(crypto.sign(pkey, data.encode(), "sha512")).decode()
        headers = {'Signature': signature, 'Accept': 'application/json'}
        res = requests.post(self.base_url, headers=headers, data=data.encode())
        if res.status_code != 201:
            print('Could not create a JWT. Status_code was: ' + str(res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)['token']

    def get_headers(self):
       return {'Authorization': 'Bearer ' + Generic.get_jwt(self), 'Accept': 'application/json'}



import requests
import json

class Domains:
    base_url='https://api.transip.nl/v6'
    base_url_domains=base_url + '/domains'
    def __init__(self, headers):
        self.headers = headers

    def list_domains(self):
        url = self.base_url_domains
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Getting domains failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def retrieve_domain(self, domain):
        url = self.base_url_domains + '/' + domain
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Retrieve domain "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def register_domain(self, data):
        url = self.base_url_domains
        res = requests.post(url, headers=self.headers, data=data)
        if res.status_code != 201:
            print('Creating/Transfering domain failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return

    def tranfer_domain(self, data):
        return Domains.register_domain(self, data)

    def update_domain(self, data):
        url = self.base_url_domains
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Creating/Transfering domain failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return

    def cancel_domain(self, domain, immediately=False):
        if immediately:
            data = '{"endTime": "immediately"}'
        else:
            data = '{"endTime": "end"}'
        url = self.base_url_domains + '/' + domain
        res = requests.delete(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Canceling domain failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return

    def get_domain_branding(self, domain):
        url = self.base_url_domains + '/' + domain + '/branding'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Get domain branding for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def update_domain_branding(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/branding'
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Update domain branding for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return

    def list_contacts(self, domain):
        url = self.base_url_domains + '/' + domain + '/contacts'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('List domain contacts for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def update_contacts(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/contacts'
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Update contacts for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return

    def list_dns_entries(self, domain):
        url=self.base_url_domains + '/' + domain + '/dns'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Getting dns entries for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def add_dns_entry(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/dns'
        res = requests.post(url, headers=self.headers, data=data)
        if res.status_code != 201:
            print('Creating dns entry for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data was: {0}'.format(data))
            exit(1)
        return

    def update_dns_entry(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/dns'
        res = requests.patch(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Updating dns entry for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return

    def update_all_dns_entries(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/dns'
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Updating all dns entries for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return

    def delete_dns_entry(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/dns'
        res = requests.delete(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Deleting dns entry for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return

    def list_dnssec_entries(self, domain):
        url=self.base_url_domains + '/' + domain + '/dnssec'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Getting dnssec entries for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def update_all_dnssec_entries(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/dnssec'
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Updating all dnssec entries for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return

    def list_nameservers(self, domain):
        url=self.base_url_domains + '/' + domain + '/nameservers'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Getting nameservers for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def update_nameservers(self, domain, data):
        url = self.base_url_domains + '/' + domain + '/nameservers'
        res = requests.put(url, headers=self.headers, data=data)
        if res.status_code != 204:
            print('Updating nameservers for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return

    def list_ssl(self, domain):
        url=self.base_url_domains + '/' + domain + '/ssl'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Listing ssl for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def whois(self, domain):
        url=self.base_url_domains + '/' + domain + '/whois'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Whois for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def whitelabel(self):
        url=self.base_url + '/whitelabel'
        res = requests.post(url, headers=self.headers)
        if res.status_code != 201:
            print('Whitelabel request failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def domain_availability(self, domain):
        url=self.base_url + '/domain-availability/' + domain
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Checking availability for "{0}" failed with status code: {1}'.format(domain, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def domains_availability(self, data):
        url=self.base_url + '/domain-availability'
        res = requests.get(url, headers=self.headers, data=data)
        if res.status_code != 200:
            print('Checking availability for multiple domains failed with status code: {0}'.format(res.status_code))
            print(res.text)
            print('Data: ' + data)
            exit(1)
        return json.loads(res.text)

    def list_tlds(self):
        url=self.base_url + '/tlds'
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Listing tlds failed with status code: {0}'.format(res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)

    def info_tld(self, tld):
        url=self.base_url + '/tlds/.' + tld
        res = requests.get(url, headers=self.headers)
        if res.status_code != 200:
            print('Getting info about tld "{0}" failed with status code: {1}'.format(tld, res.status_code))
            print(res.text)
            exit(1)
        return json.loads(res.text)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="transipApiV6", # Replace with your own username
    version="0.0.1",
    author="Jeroen van Gemert",
    author_email="pypi@jeroen.van.gemert.net",
    description="Package to interact with the V6 API of Transip ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jeromba6/transip_api_v6",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.x',
)